summaryrefslogtreecommitdiff
path: root/src/strife/p_switch.c
diff options
context:
space:
mode:
authorSamuel Villareal2010-09-14 03:42:09 +0000
committerSamuel Villareal2010-09-14 03:42:09 +0000
commitfe531d051d66611d82c233f8a02b435bece34ab6 (patch)
tree87c6be4955eebbdef64005ac8926b74d8fcbbc71 /src/strife/p_switch.c
parent61e1333c1d39b26c41478df92307543f379e6746 (diff)
downloadchocolate-doom-fe531d051d66611d82c233f8a02b435bece34ab6.tar.gz
chocolate-doom-fe531d051d66611d82c233f8a02b435bece34ab6.tar.bz2
chocolate-doom-fe531d051d66611d82c233f8a02b435bece34ab6.zip
+ Sliding door implementation
Subversion-branch: /branches/strife-branch Subversion-revision: 2084
Diffstat (limited to 'src/strife/p_switch.c')
-rw-r--r--src/strife/p_switch.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/strife/p_switch.c b/src/strife/p_switch.c
index d7705902..9ba321f7 100644
--- a/src/strife/p_switch.c
+++ b/src/strife/p_switch.c
@@ -510,11 +510,6 @@ P_UseSpecialLine
case 118: // Blazing door open
EV_VerticalDoor (line, thing);
break;
-
- //UNUSED - Door Slide Open&Close
- // case 124:
- // EV_SlidingDoor (line, thing);
- // break;
// SWITCHES
case 7:
@@ -820,8 +815,13 @@ P_UseSpecialLine
P_ChangeSwitchTexture(line,1);
break;
- case 666: // villsa [STRIFE]
- // Move wall
+ case 144:
+ // villsa [STRIFE] manual sliding door
+ EV_SlidingDoor(line, thing);
+ break;
+
+ case 666:
+ // villsa [STRIFE] Move wall
P_MoveWall(line, thing);
break;